@@ -152,9 +152,10 @@ class _TrytondMethod(object):
         self._object = model
         self._config = config
 
-    def __call__(self, *args):
-        from trytond.transaction import Transaction
+    def __call__(self, *args, **kwargs):
         from trytond.rpc import RPC
+        from trytond.tools import is_instance_method
+        from trytond.transaction import Transaction
 
         if self._name in self._object.__rpc__:
             rpc = self._object.__rpc__[self._name]
@@ -166,9 +167,10 @@ class _TrytondMethod(object):
         with Transaction().start(self._config.database_name,
                 self._config.user, readonly=rpc.readonly) as transaction:
             args, kwargs, transaction.context, transaction.timestamp = \
-                rpc.convert(self._object, *args)
+                rpc.convert(self._object, *args, **kwargs)
             meth = getattr(self._object, self._name)
-            if not hasattr(meth, 'im_self') or meth.im_self:
+            if (rpc.instantiate is None
+                    or not is_instance_method(self._object, self._name)):
                 result = rpc.result(meth(*args, **kwargs))
             else:
                 assert rpc.instantiate == 0
