@@ -1,12 +1,14 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-__all__ = ['PYSONEncoder', 'PYSONDecoder', 'Eval', 'Not', 'Bool', 'And', 'Or',
-    'Equal', 'Greater', 'Less', 'If', 'Get', 'In', 'Date', 'DateTime', 'Len']
 import json
 import datetime
 from dateutil.relativedelta import relativedelta
+from decimal import Decimal
 from functools import reduce, wraps
 
+__all__ = ['PYSONEncoder', 'PYSONDecoder', 'Eval', 'Not', 'Bool', 'And', 'Or',
+    'Equal', 'Greater', 'Less', 'If', 'Get', 'In', 'Date', 'DateTime', 'Len']
+
 
 def reduced_type(types):
     types = types.copy()
@@ -119,6 +121,8 @@ class PYSONEncoder(json.JSONEncoder):
                         ).pyson()
             else:
                 return Date(obj.year, obj.month, obj.day).pyson()
+        elif isinstance(obj, Decimal):
+            return float(obj)
         return super(PYSONEncoder, self).default(obj)
 
 
